/*-------------- Telecommunications & Signal Processing Lab ---------------
                             McGill University

Routine:
  void ADprintOPort (int audio_fd)

Purpose:
  Print the output port parameters for the Sun audio device

Description:
  This routine prints the output parameters for the Sun audio device.

Parameters:
   -> int audio_fd
      File descriptor for the audio device

Author / revision:
  P. Kabal  Copyright (C) 1999
  $Revision: 1.12 $  $Date: 1999/06/14 16:18:44 $

-------------------------------------------------------------------------*/

static char rcsid[] = "$Id: ADprintOPort.c 1.12 1999/06/14 AFsp-v4r3 $";

#include <stdio.h>
#include <unistd.h>		/* ioctl */
#include <sys/ioctl.h>

#include <libtsp.h>
#include <AD.h>

#define FSET(flag,mask)		(((flag) & (mask)) != 0)
#define PGM			(UTgetProg ())


void
ADprintOPort (int audio_fd)

{
   audio_info_t aif;
   int iost;

   iost = ioctl (audio_fd, AUDIO_GETINFO, &aif);
   if (iost == -1)
       UTerror ("%s: %s", PGM, ADM_GetErr);

/* Note that for some audio devices, the granularity of the gain is 8,
   i.e. the gain takes on values 0, 8, 16, ...,  240, 248, 255 */
  printf (ADMF_VolBal,
	  (100.0 * aif.play.gain) / AUDIO_MAX_GAIN,
	  (100.0 * aif.play.balance) / AUDIO_RIGHT_BALANCE);
  printf ("  ports:");
  if (FSET (aif.play.port, AUDIO_SPEAKER))
    printf (" speaker");
  if (FSET (aif.play.port, AUDIO_HEADPHONE))
    printf (" headphone");
  if (FSET (aif.play.port, AUDIO_LINE_OUT))
    printf (" line_out");
  if (aif.play.port == 0)
    printf (" (none)");
  if (aif.output_muted != 0)
    printf (" (output muted)");
  printf ("\n");

   return;
}
