/*-------------- Telecommunications & Signal Processing Lab ---------------
                             McGill University

Routine:
  int AFrdI4 (AFILE *AFp, float Fbuff[], int Nreq)

Purpose:
  Read 32-bit integer data from an audio file (return float values)

Description:
  This routine reads a specified number of 32-bit integer samples from an audio
  file.  The data in the file is converted to float format on output.

Parameters:
  <-  int AFrdI4
      Number of data values transferred from the file.  On reaching the end of
      the file, this value may be less than Nreq.
   -> AFILE *AFp
      Audio file pointer for an audio file opened by AFopenRead
  <-  float Fbuff[]
      Array of floats to receive the samples
   -> int Nreq
      Number of samples requested.  Nreq may be zero.

Author / revision:
  P. Kabal  Copyright (C) 1999
  $Revision: 1.3 $  $Date: 1999/06/11 22:32:07 $

-------------------------------------------------------------------------*/

static char rcsid [] = "$Id: AFrdI4.c 1.3 1999/06/11 AFsp-v4r3 $";

#include <libtsp/AFdataio.h>
#include <libtsp/AFpar.h>
#include <libtsp/UTtypes.h>

#define LW		FDL_INT32
#define MINV(a, b)	(((a) < (b)) ? (a) : (b))
#define NBBUF		8192

#define FREAD(buf,size,nv,fp)	(int) fread ((char *) buf, (size_t) size, \
					     (size_t) nv, fp)


int
AFrdI4 (AFILE *AFp, float Fbuff[], int Nreq)

{
  int is, N, i, Nr;
  int4_t Buf[NBBUF/LW];
  unsigned char *cp;
  unsigned char t;
  double g;

  for (is = 0; is < Nreq; ) {

    /* Read data from the audio file */
    N = MINV (NBBUF / LW, Nreq - is);
    Nr = FREAD (Buf, LW, N, AFp->fp);

    /* Byte swap and convert to float */
    g = AFp->ScaleF;
    for (i = 0; i < Nr; ++i) {
      if (AFp->Swapb == DS_SWAP) {
	cp = (unsigned char *) &Buf[i];
	t = cp[3]; cp[3] = cp[0]; cp[0] = t;
	t = cp[2]; cp[2] = cp[1]; cp[1] = t;
      }
      Fbuff[is] = (float) (g * Buf[i]);
      ++is;
    }

    if (Nr < N)
      break;
  }

  return is;
}
