/*-------------- Telecommunications & Signal Processing Lab ---------------
                             McGill University

Routine:
  char *UTgetHost (void)

Purpose:
  Get the host name

Description:
  This routine returns the host machine name.  Under MSDOS, a zero-length
  string is returned.

Parameters:
  <-  char UTgetHost[]
      Pointer to a character string containing the host name.  This string is
      null terminated.  This is a pointer to an internal static storage area;
      each call to this routine overlays this storage.

Author / revision:
  P. Kabal  Copyright (C) 1999
  $Revision: 1.15 $  $Date: 1999/06/12 23:53:18 $

-------------------------------------------------------------------------*/

static char rcsid[] = "$Id: UTgetHost.c 1.15 1999/06/12 AFsp-v4r3 $";

#include <stdlib.h>	/* getenv */
#include <string.h>

#include <libtsp.h>
#include <libtsp/nucleus.h>
#include <libtsp/sysOS.h>
#include <libtsp/UTmsg.h>

#define NELEM(array)	((sizeof array) / (sizeof array[0]))

#if (SY_POSIX)
#  include <sys/param.h>		/* MAXHOSTNAMELEN on many systems */
#  ifndef MAXHOSTNAMELEN
#    include <netdb.h>			/* For Sun Solaris */
#    ifndef MAXHOSTNAMELEN		/* Last resort */
#      define MAXHOSTNAMELEN	257
#    endif
#  endif
#  include <sys/utsname.h>		/* Use uname */
#else
#  define MAXHOSTNAMELEN	257
#endif

static const char *HostEnv[] = { "HOST", "HOSTNAME", "COMPUTERNAME" };
#define NENV	NELEM(HostEnv)


char *
UTgetHost (void)

{
  static char Host[MAXHOSTNAMELEN+1];
  char *p;
  int i;


#if (SY_POSIX)
  struct utsname UnameStruct;

  Host[0] = '\0';
  if (uname (&UnameStruct) >= 0) {
    strcpy (Host, UnameStruct.nodename);
    return Host;
  }

#endif

  Host[0] = '\0';
  for (i = 0; i < NENV; ++i) {
    p = getenv (HostEnv[i]);
    if (p != NULL) {
      STcopyMax (p, Host, MAXHOSTNAMELEN);
      break;
    }
  }

  return Host;
}
